@@ -7,7 +7,6 @@
 #include <tuple>
 #include <type_traits>
 
-#include "zeek/Dict.h"
 #include "zeek/IPAddr.h"
 #include "zeek/IntrusivePtr.h"
 #include "zeek/Rule.h"
@@ -65,14 +64,12 @@ struct ConnTuple
 	{
 	IPAddr src_addr;
 	IPAddr dst_addr;
-	uint32_t src_port;
-	uint32_t dst_port;
-	bool is_one_way; // if true, don't canonicalize order
-	TransportProto proto;
+	uint32_t src_port = 0;
+	uint32_t dst_port = 0;
+	bool is_one_way = false; // if true, don't canonicalize order
+	TransportProto proto = TRANSPORT_UNKNOWN;
 	};
 
-using ConnID [[deprecated("Remove in v5.1. Use zeek::ConnTuple.")]] = ConnTuple;
-
 static inline int addr_port_canon_lt(const IPAddr& addr1, uint32_t p1, const IPAddr& addr2,
                                      uint32_t p2)
 	{
@@ -195,14 +192,6 @@ public:
 
 	// Statistics.
 
-	// Just a lower bound.
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] unsigned int
-	MemoryAllocation() const override;
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] unsigned int
-	MemoryAllocationVal() const override;
-
 	static uint64_t TotalConnections() { return total_connections; }
 	static uint64_t CurrentConnections() { return current_connections; }
 
@@ -230,6 +219,9 @@ public:
 
 	void AddHistory(char code) { history += code; }
 
+	const std::string& GetHistory() const { return history; }
+	void ReplaceHistory(std::string new_h) { history = std::move(new_h); }
+
 	// Sets the root of the analyzer tree as well as the primary PIA.
 	void SetSessionAdapter(packet_analysis::IP::SessionAdapter* aa, analyzer::pia::PIA* pia);
 	packet_analysis::IP::SessionAdapter* GetSessionAdapter() { return adapter; }
