@@ -27,11 +27,11 @@ namespace detail
 
 class Frame;
 class Scope;
-struct function_ingredients;
+class FunctionIngredients;
 using IDPtr = IntrusivePtr<ID>;
 using ScopePtr = IntrusivePtr<Scope>;
 
-enum BroExprTag : int
+enum ExprTag : int
 	{
 	EXPR_ANY = -1,
 	EXPR_NAME,
@@ -53,6 +53,8 @@ enum BroExprTag : int
 	EXPR_AND,
 	EXPR_OR,
 	EXPR_XOR,
+	EXPR_LSHIFT,
+	EXPR_RSHIFT,
 	EXPR_AND_AND,
 	EXPR_OR_OR,
 	EXPR_LT,
@@ -104,7 +106,9 @@ enum BroExprTag : int
 #define NUM_EXPRS (int(EXPR_NOP) + 1)
 	};
 
-extern const char* expr_name(BroExprTag t);
+using BroExprTag [[deprecated("Remove in v6.1. Use ExprTag.")]] = ExprTag;
+
+extern const char* expr_name(ExprTag t);
 
 class AddToExpr;
 class AnyIndexExpr;
@@ -151,7 +155,7 @@ public:
 
 	template <class T> IntrusivePtr<T> GetType() const { return cast_intrusive<T>(type); }
 
-	BroExprTag Tag() const { return tag; }
+	ExprTag Tag() const { return tag; }
 
 	Expr* Ref()
 		{
@@ -416,13 +420,13 @@ public:
 
 protected:
 	Expr() = default;
-	explicit Expr(BroExprTag arg_tag);
+	explicit Expr(ExprTag arg_tag);
 
 	virtual void ExprDescribe(ODesc* d) const = 0;
 	void AddTag(ODesc* d) const;
 
 	// Puts the expression in canonical form.
-	virtual void Canonicize();
+	virtual void Canonicalize();
 
 	void SetType(TypePtr t);
 
@@ -435,7 +439,7 @@ protected:
 	[[noreturn]] void RuntimeError(const std::string& msg) const;
 	[[noreturn]] void RuntimeErrorWithCallStack(const std::string& msg) const;
 
-	BroExprTag tag;
+	ExprTag tag;
 	bool paren;
 	TypePtr type;
 
@@ -533,7 +537,7 @@ public:
 	void SetOp1(ExprPtr _op) override final { op = std::move(_op); }
 
 protected:
-	UnaryExpr(BroExprTag arg_tag, ExprPtr arg_op);
+	UnaryExpr(ExprTag arg_tag, ExprPtr arg_op);
 
 	void ExprDescribe(ODesc* d) const override;
 
@@ -573,7 +577,7 @@ public:
 	void SetOp2(ExprPtr _op) override final { op2 = std::move(_op); }
 
 protected:
-	BinaryExpr(BroExprTag arg_tag, ExprPtr arg_op1, ExprPtr arg_op2)
+	BinaryExpr(ExprTag arg_tag, ExprPtr arg_op1, ExprPtr arg_op2)
 		: Expr(arg_tag), op1(std::move(arg_op1)), op2(std::move(arg_op2))
 		{
 		if ( ! (op1 && op2) )
@@ -620,14 +624,6 @@ protected:
 
 	void ExprDescribe(ODesc* d) const override;
 
-	// Reports on if this BinaryExpr involves a scalar and aggregate
-	// type (vec, list, table, record).
-	bool IsScalarAggregateOp() const;
-
-	// Warns about deprecated scalar vector operations like
-	// `[1, 2, 3] == 1` or `["a", "b", "c"] + "a"`.
-	void CheckScalarAggOp() const;
-
 	// For assignment operations (=, +=, -=) checks for a valid
 	// expression-list on the RHS (op2), potentially transforming
 	// op2 in the process.  Returns true if the list is present
@@ -654,7 +650,7 @@ protected:
 class IncrExpr final : public UnaryExpr
 	{
 public:
-	IncrExpr(BroExprTag tag, ExprPtr op);
+	IncrExpr(ExprTag tag, ExprPtr op);
 
 	ValPtr Eval(Frame* f) const override;
 	ValPtr DoSingleEval(Frame* f, Val* v) const;
@@ -743,7 +739,7 @@ class AddExpr final : public BinaryExpr
 	{
 public:
 	AddExpr(ExprPtr op1, ExprPtr op2);
-	void Canonicize() override;
+	void Canonicalize() override;
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -805,7 +801,7 @@ class TimesExpr final : public BinaryExpr
 	{
 public:
 	TimesExpr(ExprPtr op1, ExprPtr op2);
-	void Canonicize() override;
+	void Canonicalize() override;
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -839,7 +835,7 @@ public:
 class BoolExpr final : public BinaryExpr
 	{
 public:
-	BoolExpr(BroExprTag tag, ExprPtr op1, ExprPtr op2);
+	BoolExpr(ExprTag tag, ExprPtr op1, ExprPtr op2);
 
 	ValPtr Eval(Frame* f) const override;
 	ValPtr DoSingleEval(Frame* f, ValPtr v1, Expr* op2) const;
@@ -858,7 +854,7 @@ protected:
 class BitExpr final : public BinaryExpr
 	{
 public:
-	BitExpr(BroExprTag tag, ExprPtr op1, ExprPtr op2);
+	BitExpr(ExprTag tag, ExprPtr op1, ExprPtr op2);
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -869,8 +865,8 @@ public:
 class EqExpr final : public BinaryExpr
 	{
 public:
-	EqExpr(BroExprTag tag, ExprPtr op1, ExprPtr op2);
-	void Canonicize() override;
+	EqExpr(ExprTag tag, ExprPtr op1, ExprPtr op2);
+	void Canonicalize() override;
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -885,8 +881,8 @@ protected:
 class RelExpr final : public BinaryExpr
 	{
 public:
-	RelExpr(BroExprTag tag, ExprPtr op1, ExprPtr op2);
-	void Canonicize() override;
+	RelExpr(ExprTag tag, ExprPtr op1, ExprPtr op2);
+	void Canonicalize() override;
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -951,7 +947,7 @@ public:
 	bool HasReducedOps(Reducer* c) const override;
 	ExprPtr Reduce(Reducer* c, StmtPtr& red_stmt) override;
 
-	// Reduce to simplifed LHS form, i.e., a reference to only a name.
+	// Reduce to simplified LHS form, i.e., a reference to only a name.
 	StmtPtr ReduceToLHS(Reducer* c);
 	};
 
@@ -1458,12 +1454,12 @@ protected:
 class LambdaExpr final : public Expr
 	{
 public:
-	LambdaExpr(std::unique_ptr<function_ingredients> ingredients, IDPList outer_ids,
+	LambdaExpr(std::unique_ptr<FunctionIngredients> ingredients, IDPList outer_ids,
 	           StmtPtr when_parent = nullptr);
 
 	const std::string& Name() const { return my_name; }
 	const IDPList& OuterIDs() const { return outer_ids; }
-	const function_ingredients& Ingredients() const { return *ingredients; }
+	const FunctionIngredients& Ingredients() const { return *ingredients; }
 
 	ValPtr Eval(Frame* f) const override;
 	TraversalCode Traverse(TraversalCallback* cb) const override;
@@ -1480,13 +1476,11 @@ protected:
 	void ExprDescribe(ODesc* d) const override;
 
 private:
-	void CheckCaptures(StmtPtr when_parent);
+	bool CheckCaptures(StmtPtr when_parent);
 
-	std::unique_ptr<function_ingredients> ingredients;
+	std::unique_ptr<FunctionIngredients> ingredients;
 	IDPtr lambda_id;
-
 	IDPList outer_ids;
-	bool capture_by_ref; // if true, use deprecated reference semantics
 
 	std::string my_name;
 	};
