@@ -47,6 +47,9 @@ class ScriptFunc;
 
 	} // namespace detail
 
+class EventGroup;
+using EventGroupPtr = std::shared_ptr<EventGroup>;
+
 class Func;
 using FuncPtr = IntrusivePtr<Func>;
 
@@ -70,6 +73,11 @@ public:
 		{
 		detail::StmtPtr stmts;
 		int priority;
+		std::set<EventGroupPtr> groups;
+		// If any of the groups are disabled, this body is disabled.
+		// The disabled field is updated from EventGroup instances.
+		bool disabled = false;
+
 		bool operator<(const Body& other) const
 			{
 			return priority > other.priority;
@@ -77,7 +85,14 @@ public:
 		};
 
 	const std::vector<Body>& GetBodies() const { return bodies; }
-	bool HasBodies() const { return bodies.size(); }
+	bool HasBodies() const { return ! bodies.empty(); }
+
+	/**
+	 * Are there bodies and is any one of them enabled?
+	 *
+	 * @return  true if bodies exist and at least one is enabled.
+	 */
+	bool HasEnabledBodies() const { return ! bodies.empty() && has_enabled_bodies; };
 
 	/**
 	 * Calls a Zeek function.
@@ -99,6 +114,11 @@ public:
 		return Invoke(&zargs);
 		}
 
+	// Add a new event handler to an existing function (event).
+	virtual void AddBody(detail::StmtPtr new_body, const std::vector<detail::IDPtr>& new_inits,
+	                     size_t new_frame_size, int priority,
+	                     const std::set<EventGroupPtr>& groups);
+
 	// Add a new event handler to an existing function (event).
 	virtual void AddBody(detail::StmtPtr new_body, const std::vector<detail::IDPtr>& new_inits,
 	                     size_t new_frame_size, int priority = 0);
@@ -134,6 +154,13 @@ protected:
 	Kind kind = SCRIPT_FUNC;
 	FuncTypePtr type;
 	std::string name;
+
+private:
+	// EventGroup updates Func::Body.disabled and has_enabled_bodies.
+	// This is friend/private with EventGroup here so that we do not
+	// expose accessors in the zeek:: public interface.
+	friend class EventGroup;
+	bool has_enabled_bodies = true;
 	};
 
 namespace detail
@@ -142,8 +169,7 @@ namespace detail
 class ScriptFunc : public Func
 	{
 public:
-	ScriptFunc(const IDPtr& id, StmtPtr body, const std::vector<IDPtr>& inits, size_t frame_size,
-	           int priority);
+	ScriptFunc(const IDPtr& id);
 
 	// For compiled scripts.
 	ScriptFunc(std::string name, FuncTypePtr ft, std::vector<StmtPtr> bodies,
@@ -182,42 +208,12 @@ public:
 	 */
 	const OffsetMap* GetCapturesOffsetMap() const { return captures_offset_mapping; }
 
-	// The following "Closure" methods implement the deprecated
-	// capture-by-reference functionality.
-
 	/**
-	 * Adds a closure to the function. Closures are cloned and
-	 * future calls to ScriptFunc methods will not modify *f*.
+	 * Serializes this function's capture frame.
 	 *
-	 * @param ids IDs that are captured by the closure.
-	 * @param f the closure to be captured.
+	 * @return a serialized version of the function's capture frame.
 	 */
-	void AddClosure(IDPList ids, Frame* f);
-
-	/**
-	 * Replaces the current closure with one built from *data*
-	 *
-	 * @param data a serialized closure
-	 */
-	bool UpdateClosure(const broker::vector& data);
-
-	/**
-	 * If the function's closure is a weak reference to the given frame,
-	 * upgrade to a strong reference of a shallow clone of that frame.
-	 */
-	bool StrengthenClosureReference(Frame* f);
-
-	/**
-	 * Whether the function's closure uses copy semantics.
-	 */
-	virtual bool HasCopySemantics() const;
-
-	/**
-	 * Serializes this function's closure or capture frame.
-	 *
-	 * @return a serialized version of the function's closure/capture frame.
-	 */
-	virtual broker::expected<broker::data> SerializeClosure() const;
+	virtual broker::expected<broker::data> SerializeCaptures() const;
 
 	/**
 	 * Sets the captures frame to one built from *data*.
@@ -226,8 +222,11 @@ public:
 	 */
 	bool DeserializeCaptures(const broker::vector& data);
 
-	void AddBody(StmtPtr new_body, const std::vector<IDPtr>& new_inits, size_t new_frame_size,
-	             int priority) override;
+	using Func::AddBody;
+
+	void AddBody(detail::StmtPtr new_body, const std::vector<detail::IDPtr>& new_inits,
+	             size_t new_frame_size, int priority,
+	             const std::set<EventGroupPtr>& groups) override;
 
 	/**
 	 * Replaces the given current instance of a function body with
@@ -267,18 +266,10 @@ protected:
 	StmtPtr AddInits(StmtPtr body, const std::vector<IDPtr>& inits);
 
 	/**
-	 * Clones this function along with its closures.
+	 * Clones this function along with its captures.
 	 */
 	FuncPtr DoClone() override;
 
-	/**
-	 * Performs a selective clone of *f* using the IDs that were
-	 * captured in the function's closure.
-	 *
-	 * @param f the frame to be cloned.
-	 */
-	void SetClosureFrame(Frame* f);
-
 	/**
 	 * Uses the given frame for captures, and generates the
 	 * mapping from captured variables to offsets in the frame.
@@ -293,13 +284,7 @@ private:
 	// List of the outer IDs used in the function.
 	IDPList outer_ids;
 
-	// The following is used for deprecated capture-by-reference
-	// closures:
-	// The frame the ScriptFunc was initialized in.
-	Frame* closure = nullptr;
-	bool weak_closure_ref = false;
-
-	// Used for capture-by-copy closures.  These persist over the
+	// Frame for (capture-by-copy) closures.  These persist over the
 	// function's lifetime, providing quasi-globals that maintain
 	// state across individual calls to the function.
 	Frame* captures_frame = nullptr;
@@ -349,19 +334,32 @@ struct CallInfo
 
 // Struct that collects all the specifics defining a Func. Used for ScriptFuncs
 // with closures.
-struct function_ingredients
+class FunctionIngredients
 	{
-
+public:
 	// Gathers all of the information from a scope and a function body needed
 	// to build a function.
-	function_ingredients(ScopePtr scope, StmtPtr body);
+	FunctionIngredients(ScopePtr scope, StmtPtr body, const std::string& module_name);
 
+	const IDPtr& GetID() const { return id; }
+
+	const StmtPtr& Body() const { return body; }
+	void SetBody(StmtPtr _body) { body = std::move(_body); }
+
+	const auto& Inits() const { return inits; }
+	size_t FrameSize() const { return frame_size; }
+	int Priority() const { return priority; }
+	const ScopePtr& Scope() const { return scope; }
+	const auto& Groups() const { return groups; }
+
+private:
 	IDPtr id;
 	StmtPtr body;
 	std::vector<IDPtr> inits;
-	int frame_size = 0;
+	size_t frame_size = 0;
 	int priority = 0;
 	ScopePtr scope;
+	std::set<EventGroupPtr> groups;
 	};
 
 extern std::vector<CallInfo> call_stack;
