@@ -22,6 +22,7 @@ namespace zeek
 class Val;
 union ZVal;
 class EnumVal;
+class RecordVal;
 class TableVal;
 using ValPtr = IntrusivePtr<Val>;
 using EnumValPtr = IntrusivePtr<EnumVal>;
@@ -35,6 +36,16 @@ class ListExpr;
 class Attributes;
 using ListExprPtr = IntrusivePtr<ListExpr>;
 
+// The following tracks how to initialize a given record field.
+class FieldInit
+	{
+public:
+	virtual ~FieldInit() { }
+
+	// Return the initialization value of the field.
+	virtual ZVal Generate() const = 0;
+	};
+
 	} // namespace detail
 
 // Zeek types.
@@ -252,10 +263,6 @@ public:
 	void Describe(ODesc* d) const override;
 	virtual void DescribeReST(ODesc* d, bool roles_only = false) const;
 
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] virtual unsigned
-	MemoryAllocation() const;
-
 	void SetName(const std::string& arg_name) { name = arg_name; }
 	const std::string& GetName() const { return name; }
 
@@ -343,6 +350,10 @@ public:
 	// is not pure or is empty.
 	const TypePtr& GetPureType() const { return pure_type; }
 
+	// Retrospectively instantiates an underlying pure type, if in
+	// fact each element has the same type.
+	void CheckPure();
+
 	// True if all of the types match t, false otherwise.  If
 	// is_init is true, then the matching is done in the context
 	// of an initialization.
@@ -352,10 +363,6 @@ public:
 	void Append(TypePtr t);
 	void AppendEvenIfNotPure(TypePtr t);
 
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] unsigned int
-	MemoryAllocation() const override;
-
 	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
 
 protected:
@@ -454,7 +461,7 @@ public:
 		std::string deprecation_msg;
 		RecordTypePtr args;
 		// Maps from parameter index in canonical prototype to
-		// parameter index in this alternate prorotype.
+		// parameter index in this alternate prototype.
 		std::map<int, int> offsets;
 		};
 
@@ -587,6 +594,8 @@ public:
 	TypeDecl(const TypeDecl& other);
 	~TypeDecl();
 
+	TypeDecl& operator=(const TypeDecl& other);
+
 	const detail::AttrPtr& GetAttr(detail::AttrTag a) const
 		{
 		return attrs ? attrs->Find(a) : detail::Attr::nil;
@@ -601,11 +610,6 @@ public:
 
 using type_decl_list = PList<TypeDecl>;
 
-// The following tracks how to initialize a given field.  We don't define
-// it here because it requires pulling in a bunch of low-level headers that
-// would be nice to avoid.
-class FieldInit;
-
 class RecordType final : public Type
 	{
 public:
@@ -689,7 +693,9 @@ public:
 	 * Populates a new instance of the record with its initial values.
 	 * @param r  The record's underlying value vector.
 	 */
-	void Create(std::vector<std::optional<ZVal>>& r) const;
+	[[deprecated("Remove in v6.1. Construct a corresponding RecordVal and build vector from "
+	             "GetFieldAs() calls.")]] void
+	Create(std::vector<std::optional<ZVal>>& r) const;
 
 	void DescribeReST(ODesc* d, bool roles_only = false) const override;
 	void DescribeFields(ODesc* d) const;
@@ -711,28 +717,42 @@ public:
 
 	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
 
-protected:
+private:
 	RecordType() { types = nullptr; }
 
 	void AddField(unsigned int field, const TypeDecl* td);
 
 	void DoDescribe(ODesc* d) const override;
 
-	// Maps each field to how to initialize it.  Uses pointers due to
-	// keeping the FieldInit definition private to Type.cc (see above).
-	std::vector<FieldInit*> field_inits;
+	// Field initializations that can be deferred to first access,
+	// beneficial for fields that are separately initialized prior
+	// to first access.  Nil pointers mean "skip initializing the field".
+	std::vector<std::unique_ptr<detail::FieldInit>> deferred_inits;
+
+	// Field initializations that need to be done upon record creation,
+	// rather than deferred.  These are expressions whose value might
+	// change if computed later.
+	//
+	// Such initializations are uncommon, so we represent them using
+	// <fieldoffset, init> pairs.
+	std::vector<std::pair<int, std::unique_ptr<detail::FieldInit>>> creation_inits;
+
+	friend zeek::RecordVal;
+	const auto& DeferredInits() const { return deferred_inits; }
+	const auto& CreationInits() const { return creation_inits; }
 
 	// If we were willing to bound the size of records, then we could
 	// use std::bitset here instead.
 	std::vector<bool> managed_fields;
 
 	// Number of fields in the type.
-	int num_fields;
+	int num_fields = 0;
 
 	// Number of fields in the type when originally declared.
-	int num_orig_fields;
+	int num_orig_fields = 0;
 
-	type_decl_list* types;
+	type_decl_list* types = nullptr;
+	std::set<std::string> field_ids;
 	};
 
 class FileType final : public Type
@@ -774,7 +794,7 @@ protected:
 class EnumType final : public Type
 	{
 public:
-	using enum_name_list = std::list<std::pair<std::string, bro_int_t>>;
+	using enum_name_list = std::list<std::pair<std::string, zeek_int_t>>;
 
 	explicit EnumType(const EnumType* e);
 	explicit EnumType(const std::string& arg_name);
@@ -788,16 +808,16 @@ public:
 
 	// The value of this name is set to val. Once a value has been
 	// explicitly assigned using this method, no further names can be
-	// added that aren't likewise explicitly initalized.
-	void AddName(const std::string& module_name, const char* name, bro_int_t val, bool is_export,
+	// added that aren't likewise explicitly initialized.
+	void AddName(const std::string& module_name, const char* name, zeek_int_t val, bool is_export,
 	             detail::Expr* deprecation = nullptr, bool from_redef = false);
 
 	// -1 indicates not found.  Second version is for full names
 	// that already incorporate the module.
-	bro_int_t Lookup(const std::string& module_name, const char* name) const;
-	bro_int_t Lookup(const std::string& full_name) const;
+	zeek_int_t Lookup(const std::string& module_name, const char* name) const;
+	zeek_int_t Lookup(const std::string& full_name) const;
 
-	const char* Lookup(bro_int_t value) const; // Returns 0 if not found
+	const char* Lookup(zeek_int_t value) const; // Returns 0 if not found
 
 	// Returns the list of defined names with their values. The names
 	// will be fully qualified with their module name.
@@ -807,30 +827,30 @@ public:
 
 	void DescribeReST(ODesc* d, bool roles_only = false) const override;
 
-	const EnumValPtr& GetEnumVal(bro_int_t i);
+	const EnumValPtr& GetEnumVal(zeek_int_t i);
 
 	// Only for use by C++-generated code.  Non-protected because we
 	// don't know in advance the names of the functions that will
 	// access it.
-	void AddNameInternal(const std::string& full_name, bro_int_t val);
+	void AddNameInternal(const std::string& full_name, zeek_int_t val);
 
 protected:
-	void AddNameInternal(const std::string& module_name, const char* name, bro_int_t val,
+	void AddNameInternal(const std::string& module_name, const char* name, zeek_int_t val,
 	                     bool is_export);
 
-	void CheckAndAddName(const std::string& module_name, const char* name, bro_int_t val,
+	void CheckAndAddName(const std::string& module_name, const char* name, zeek_int_t val,
 	                     bool is_export, detail::Expr* deprecation = nullptr,
 	                     bool from_redef = false);
 
 	void DoDescribe(ODesc* d) const override;
 
-	using NameMap = std::map<std::string, bro_int_t>;
+	using NameMap = std::map<std::string, zeek_int_t>;
 	NameMap names;
 
 	// Whether any of the elements of the enum were added via redef's.
 	bool has_redefs = false;
 
-	using ValMap = std::unordered_map<bro_int_t, EnumValPtr>;
+	using ValMap = std::unordered_map<zeek_int_t, EnumValPtr>;
 	ValMap vals;
 
 	// The counter is initialized to 0 and incremented on every implicit
@@ -839,7 +859,7 @@ protected:
 	// specified, the counter is set to -1. This way counter can be used
 	// as a flag to prevent mixing of auto-increment and explicit
 	// enumerator specifications.
-	bro_int_t counter;
+	zeek_int_t counter;
 	};
 
 class VectorType final : public Type
@@ -932,7 +952,13 @@ TypePtr merge_types(const TypePtr& t1, const TypePtr& t2);
 // Given a list of expressions, returns a (ref'd) type reflecting
 // a merged type consistent across all of them, or nil if this
 // cannot be done.
-TypePtr merge_type_list(detail::ListExpr* elements);
+[[deprecated("Remove in v6.1. Use maximal_type() if possible. See GH-2604.")]] TypePtr
+merge_type_list(detail::ListExpr* elements);
+
+// Given a list of expressions, returns the maximal type consistent across
+// all of them, or nil if this cannot be done.  "Maximal" incorporates
+// notions of arithmetic coercion, but otherwise requires type-equivalence.
+TypePtr maximal_type(detail::ListExpr* elements);
 
 // Given an expression, infer its type when used for an initialization.
 TypePtr init_type(const detail::ExprPtr& init);
@@ -991,19 +1017,19 @@ inline bool IsFunc(TypeTag t)
 	return (t == TYPE_FUNC);
 	}
 
-// True if the given type type is a vector.
+// True if the given type tag is a vector.
 inline bool IsVector(TypeTag t)
 	{
 	return (t == TYPE_VECTOR);
 	}
 
-// True if the given type type is a string.
+// True if the given type tag is a string.
 inline bool IsString(TypeTag t)
 	{
 	return (t == TYPE_STRING);
 	}
 
-// True if the given type is a container aggregate.
+// True if the given type is an aggregate.
 inline bool IsAggr(TypeTag tag)
 	{
 	return tag == TYPE_VECTOR || tag == TYPE_TABLE || tag == TYPE_RECORD;
@@ -1017,6 +1043,12 @@ inline bool IsAggr(const TypePtr& t)
 	return IsAggr(t->Tag());
 	}
 
+// True if the given type is a container.
+inline bool IsContainer(TypeTag tag)
+	{
+	return tag == TYPE_VECTOR || tag == TYPE_TABLE;
+	}
+
 // True if the given type tag corresponds to the error type.
 inline bool IsErrorType(TypeTag t)
 	{
