@@ -46,7 +46,7 @@ public:
 	String(std::string_view str);
 	String(const String& bs);
 
-	// Constructor that takes owernship of the vector passed in.
+	// Constructor that takes ownership of the vector passed in.
 	String(bool arg_final_NUL, byte_vec str, int arg_n);
 
 	String();
@@ -101,9 +101,12 @@ public:
 	static constexpr int EXPANDED_STRING = // the original style
 		ESC_HEX;
 
-	static constexpr int BRO_STRING_LITERAL = // as in a Bro/Zeek string literal
+	static constexpr int ZEEK_STRING_LITERAL = // as in a Zeek string literal
 		ESC_ESC | ESC_QUOT | ESC_HEX;
 
+	static constexpr int BRO_STRING_LITERAL
+		[[deprecated("Remove in v6.1. Use ZEEK_STRING_LITERAL.")]] = ZEEK_STRING_LITERAL;
+
 	// Renders a string into a newly allocated character array that
 	// you have to delete[].  You can combine the render styles given
 	// above to achieve the representation you desire.  If you pass a
@@ -130,10 +133,6 @@ public:
 	// XXX and to_upper; the latter doesn't use String::ToUpper().
 	void ToUpper();
 
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] unsigned int
-	MemoryAllocation() const;
-
 	// Returns new string containing the substring of this string,
 	// starting at @start >= 0 for going up to @length elements,
 	// A negative @length means "until end of string".  Other invalid
