@@ -1,11 +1,14 @@
 #pragma once
 
 #include "zeek/analyzer/protocol/tcp/TCP.h"
+
 #include "analyzer/protocol/smb/smb_pac.h"
 
-namespace zeek::analyzer::smb {
+namespace zeek::analyzer::smb
+	{
 
-class SMB_Analyzer final : public analyzer::tcp::TCP_ApplicationAnalyzer {
+class SMB_Analyzer final : public analyzer::tcp::TCP_ApplicationAnalyzer
+	{
 public:
 	explicit SMB_Analyzer(Connection* conn);
 	~SMB_Analyzer() override;
@@ -18,8 +21,7 @@ public:
 	bool HasSMBHeader(int len, const u_char* data);
 	void NeedResync();
 
-	static analyzer::Analyzer* Instantiate(Connection* conn)
-		{ return new SMB_Analyzer(conn); }
+	static analyzer::Analyzer* Instantiate(Connection* conn) { return new SMB_Analyzer(conn); }
 
 protected:
 	binpac::SMB::SMB_Conn* interp;
@@ -29,12 +31,6 @@ protected:
 	uint8_t chunks;
 
 	bool need_sync;
-};
+	};
 
-} // namespace zeek::analyzer::smb
-
-namespace analyzer::smb {
-
-using SMB_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::smb::SMB_Analyzer.")]] = zeek::analyzer::smb::SMB_Analyzer;
-
-} // namespace analyzer::smb
+	} // namespace zeek::analyzer::smb
