@@ -84,6 +84,7 @@ public:
 
 protected:
 	friend class analyzer::tcp::TCP_ApplicationAnalyzer;
+	friend class analyzer::tcp::TCP_Endpoint;
 	friend class analyzer::tcp::TCP_Reassembler;
 	friend class analyzer::pia::PIA_TCP;
 	friend class packet_analysis::TCP::TCPAnalyzer;
@@ -99,12 +100,13 @@ protected:
 	bool IsReuse(double t, const u_char* pkt) override;
 
 	void SetPartialStatus(analyzer::tcp::TCP_Flags flags, bool is_orig);
+	void SetFirstPacketSeen(bool is_orig);
 
 	// Update the state machine of the TCPs based on the activity.  This
 	// includes our pseudo-states such as TCP_ENDPOINT_PARTIAL.
 	//
 	// On return, do_close is true if we should consider the connection
-	// as closed, and gen_event if we shouuld generate an event about
+	// as closed, and gen_event if we should generate an event about
 	// this fact.
 	void UpdateStateMachine(double t, analyzer::tcp::TCP_Endpoint* endpoint,
 	                        analyzer::tcp::TCP_Endpoint* peer, uint32_t base_seq, uint32_t ack_seq,
