@@ -15,13 +15,14 @@
 #endif
 
 #include <libgen.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <unistd.h>
 #include <array>
 #include <cinttypes>
+#include <cstdarg>
 #include <cstdint>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <memory> // std::unique_ptr
 #include <string>
 #include <string_view>
@@ -29,28 +30,32 @@
 
 #ifdef TIME_WITH_SYS_TIME
 #include <sys/time.h>
-#include <time.h>
-#else
-#ifdef HAVE_SYS_TIME_H
+#include <ctime>
+#elif defined(HAVE_SYS_TIME_H)
 #include <sys/time.h>
 #else
-#include <time.h>
-#endif
+#include <ctime>
 #endif
 
 #ifdef DEBUG
 
-#include <assert.h>
+#include <cassert>
 
+#ifdef ASSERT
+#undef ASSERT
+#endif
 #define ASSERT(x) assert(x)
-#define DEBUG_MSG(x...) fprintf(stderr, x)
+#define DEBUG_MSG(...) fprintf(stderr, __VA_ARGS__)
 #define DEBUG_fputs fputs
 
 #else
+#ifdef MSTCPIP_ASSERT_UNDEFINED
+#undef ASSERT
+#endif
 
 #define ASSERT(x)
-#define DEBUG_MSG(x...)
-#define DEBUG_fputs(x...)
+#define DEBUG_MSG(...)
+#define DEBUG_fputs(...)
 
 #endif
 
@@ -60,9 +65,15 @@
 extern HeapLeakChecker* heap_checker;
 #endif
 
-#include <pthread.h>
+#include <stdint.h>
+
+extern "C"
+	{
+#include "zeek/3rdparty/modp_numtoa.h"
+	}
 
 #ifdef HAVE_LINUX
+#include <pthread.h>
 #include <sys/prctl.h>
 #endif
 
@@ -70,19 +81,35 @@ extern HeapLeakChecker* heap_checker;
 #include <pthread_np.h>
 #endif
 
-extern "C"
+#ifdef _MSC_VER
+#include <pthread.h>
+#include <filesystem>
+namespace zeek
 	{
-#include "zeek/3rdparty/modp_numtoa.h"
+namespace filesystem = std::filesystem;
 	}
+inline constexpr std::string_view path_list_separator = ";";
+#else
+// Expose ghc::filesystem as zeek::filesystem until we can
+// switch to std::filesystem on all platforms.
+#include "zeek/3rdparty/ghc/filesystem.hpp"
+namespace zeek
+	{
+namespace filesystem = ghc::filesystem;
+	}
+inline constexpr std::string_view path_list_separator = ":";
+#endif
 
-using bro_int_t = int64_t;
-using bro_uint_t = uint64_t;
+using zeek_int_t = int64_t;
+using zeek_uint_t = uint64_t;
+using bro_int_t [[deprecated("Remove in v6.1. Use zeek_int_t.")]] = zeek_int_t;
+using bro_uint_t [[deprecated("Remove in v6.1. Use zeek_uint_t.")]] = zeek_uint_t;
 
 #ifndef HAVE_STRCASESTR
 extern char* strcasestr(const char* s, const char* find);
 #endif
 
-// This is used by the patricia code and so it remains outside of hte namespace.
+// This is used by the patricia code and so it remains outside of the namespace.
 extern "C" void out_of_memory(const char* where);
 
 namespace zeek
@@ -111,12 +138,15 @@ extern bool ensure_dir(const char* dirname);
 
 extern void hmac_md5(size_t size, const unsigned char* bytes, unsigned char digest[16]);
 
-// Initializes RNGs for zeek::random_number() and MD5 usage.  If load_file is given,
-// the seeds (both random & MD5) are loaded from that file.  This takes
-// precedence over the "use_empty_seeds" argument, which just
-// zero-initializes all seed values.  If write_file is given, the seeds are
+// Initializes RNGs for zeek::random_number() and hmac-md5/siphash/highwayhash usage.
+// If load_file is given, the seeds (both random & hashes) are loaded from that file.  This
+// takes precedence over the "seed_string and "use_empty_seeds" arguments. The content of
+// "seed_string" is used as seeds if not empty next. Otherwise, when "use_empty_seeds" is
+// set it zero-initializes all seed values. If neither of these provides initial seed values,
+// platform specific random data is used as seeds. If write_file is given, the seeds are
 // written to that file.
-extern void init_random_seed(const char* load_file, const char* write_file, bool use_empty_seeds);
+extern void init_random_seed(const char* load_file, const char* write_file, bool use_empty_seeds,
+                             const std::string& seed_string = {});
 
 // Retrieves the initial seed computed after the very first call to
 // init_random_seed(). Repeated calls to init_random_seed() will not affect
@@ -126,8 +156,6 @@ unsigned int initial_seed();
 // Returns true if the user explicitly set a seed via init_random_seed();
 extern bool have_random_seed();
 
-extern uint64_t rand64bit();
-
 /**
  * A platform-independent PRNG implementation.  Note that this is not
  * necessarily a "statistically sound" implementation as the main purpose is
@@ -180,7 +208,7 @@ using SourceID = std::uintptr_t;
 constexpr SourceID SOURCE_LOCAL = 0;
 
 // TODO: This is a temporary marker to flag events coming in via Broker.
-// Those are remote events but we don't have any further peer informationa
+// Those are remote events but we don't have any further peer information
 // available for them (as the old communication code would have). Once we
 // remove RemoteSerializer, we can turn the SourceID into a simple boolean
 // indicating whether it's a local or remote event.
@@ -255,7 +283,7 @@ void terminate_processing();
 
 // Sets the current status of the Zeek process to the given string.
 // If the option --status-file has been set, this is written into
-// the the corresponding file.  Otherwise, the function is a no-op.
+// the corresponding file.  Otherwise, the function is a no-op.
 void set_processing_status(const char* status, const char* reason);
 
 // Renames the given file to a new temporary name, and opens a new file with
@@ -280,6 +308,8 @@ double parse_rotate_base_time(const char* rotate_base_time);
 // This function is thread-safe.
 double calc_next_rotate(double current, double rotate_interval, double base);
 
+int setvbuf(FILE* stream, char* buf, int type, size_t size);
+
 	} // namespace detail
 
 template <class T> void delete_each(T* t)
@@ -312,7 +342,7 @@ std::vector<std::string>* tokenize_string(std::string_view input, std::string_vi
 std::vector<std::string_view> tokenize_string(std::string_view input, const char delim) noexcept;
 
 extern char* copy_string(const char* s);
-extern int streq(const char* s1, const char* s2);
+extern bool streq(const char* s1, const char* s2);
 extern bool starts_with(std::string_view s, std::string_view beginning);
 extern bool ends_with(std::string_view s, std::string_view ending);
 
@@ -505,7 +535,7 @@ inline char* safe_strncpy(char* dest, const char* src, size_t n)
 
 // Memory alignment helpers.
 
-inline bool is_power_of_2(bro_uint_t x)
+inline bool is_power_of_2(zeek_uint_t x)
 	{
 	return ((x - 1) & x) == 0;
 	}
@@ -547,12 +577,6 @@ std::string canonify_name(const std::string& name);
  */
 void zeek_strerror_r(int zeek_errno, char* buf, size_t buflen);
 
-/**
- * A wrapper function for getenv().  Helps check for existence of
- * legacy environment variable names that map to the latest \a name.
- */
-[[deprecated("Remove in v5.1.  Use getenv() directly.")]] char* zeekenv(const char* name);
-
 /**
  * Escapes bytes in a string that are not valid UTF8 characters with \xYY format. Used
  * by the JSON writer and BIF methods.
@@ -571,5 +595,80 @@ std::string json_escape_utf8(const std::string& val, bool escape_printable_contr
 std::string json_escape_utf8(const char* val, size_t val_size,
                              bool escape_printable_controls = true);
 
+/**
+ * Splits a string at all occurrences of a delimiter. Successive occurrences
+ * of the delimiter will be split into multiple pieces.
+ *
+ * \note This function is not UTF8-aware.
+ */
+template <typename T> std::vector<T> split(T s, const T& delim)
+	{
+	// If there's no delimiter, return a copy of the existing string.
+	if ( delim.empty() )
+		return {T(s)};
+
+	// If the delimiter won't fit in the string, just return a copy as well.
+	if ( s.size() < delim.size() )
+		return {T(s)};
+
+	std::vector<T> l;
+
+	const bool ends_in_delim = (s.substr(s.size() - delim.size()) == delim);
+
+	do
+		{
+		size_t p = s.find(delim);
+		l.push_back(s.substr(0, p));
+		if ( p == std::string::npos )
+			break;
+
+		s = s.substr(p + delim.size());
+		} while ( ! s.empty() );
+
+	if ( ends_in_delim )
+		l.emplace_back(T{});
+
+	return l;
+	}
+
+/**
+ * Specialized version of util::split that allows for differing string and delimiter types,
+ * with the requirement that the delimiter must be of the same type as what is stored in the
+ * string type. For example, this allows passing a std::string as the string to split with
+ * a const char* delimiter.
+ *
+ * @param s the string to split
+ * @param delim the delimiter to split the string on
+ * @return a vector of containing the separate parts of the string.
+ */
+template <typename T, typename U = typename T::value_type*> std::vector<T> split(T s, U delim)
+	{
+	return split(s, T{delim});
+	}
+
+/**
+ * Specialized version of util::split that takes a const char* string and delimiter.
+ *
+ * @param s the string to split
+ * @param delim the delimiter to split the string on
+ * @return a vector of string_view objects containing the separate parts of the string.
+ */
+inline std::vector<std::string_view> split(const char* s, const char* delim)
+	{
+	return split(std::string_view(s), std::string_view(delim));
+	}
+
+/**
+ * Specialized version of util::split that takes a const wchar_t* string and delimiter.
+ *
+ * @param s the string to split
+ * @param delim the delimiter to split the string on
+ * @return a vector of wstring_view objects containing the separate parts of the string.
+ */
+inline std::vector<std::wstring_view> split(const wchar_t* s, const wchar_t* delim)
+	{
+	return split(std::wstring_view(s), std::wstring_view(delim));
+	}
+
 	} // namespace util
 	} // namespace zeek
