@@ -1,9 +1,13 @@
+// See the file "COPYING" in the main distribution directory for copyright.
+
 #pragma once
 
 /* Old libpcap versions (< 0.6.1) need defining pcap_freecode and
    pcap_compile_nopcap */
 /* #undef DONT_HAVE_LIBPCAP_PCAP_FREECODE */
 
+#define DONT_HAVE_LIBPCAP_DLT_LINUX_SLL2
+
 /* should explicitly declare socket() and friends */
 /* #undef DO_SOCK_DECL */
 
@@ -52,6 +56,9 @@
 /* Define if libpcap supports pcap_dump_open_append(). */
 /* #undef HAVE_PCAP_DUMP_OPEN_APPEND */
 
+/* Define if the pcap library is winpcap or npcap */
+/* #undef HAVE_WPCAP */
+
 /* line editing & history powers */
 /* #undef HAVE_READLINE */
 
@@ -73,10 +80,6 @@
 /* Define if you have the <sys/ethernet.h> header file. */
 /* #undef HAVE_SYS_ETHERNET_H */
 
-/* Some libpcap versions use an extra parameter (error) in pcap_compile_nopcap
-   */
-/* #undef LIBPCAP_PCAP_COMPILE_NOPCAP_HAS_ERROR_PARAMETER */
-
 /* Include krb5.h */
 /* #undef NEED_KRB5_H */
 
@@ -110,6 +113,9 @@
 /* should we declare syslog() and openlog() */
 /* #undef SYSLOG_INT */
 
+/* should we use stub syslog() and openlog() */
+/* #undef USE_STUB_SYSLOG */
+
 /* Define if you have <sys/time.h> */
 #define HAVE_SYS_TIME_H
 
@@ -134,20 +140,20 @@
 /* Use the ElasticSearch writer. */
 /* #undef USE_ELASTICSEARCH */
 
-/* Version number of package */
-#define VERSION "5.0.10"
-
-// Zeek version number.
-// This is the result of (major * 10000 + minor * 100 + patch)
-// For example, 3.1.2 becomes 30102.
-#define ZEEK_VERSION_NUMBER 50010
+/* Use the sqlite reader/writer. */
+#define USE_SQLITE
 
 /* whether words are stored with the most significant byte first */
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN
 
 /* whether htonll/ntohll is defined in <arpa/inet.h> */
 /* #undef HAVE_BYTEORDER_64 */
 
+/* whether to preallocate the array of PortVal objects in ValManager. Doing
+   so is typically a performance increase, at the cost of a small amount of
+   memory. */
+#define PREALLOCATE_PORT_ARRAY
+
 /* ultrix can't hack const */
 /* #undef NEED_ULTRIX_CONST_HACK */
 #ifdef NEED_ULTRIX_CONST_HACK
@@ -186,6 +192,7 @@
 #define DLT_NFLOG 239
 #endif
 
+#ifndef _MSC_VER
 /* IPv6 Next Header values defined by RFC 3542 */
 #define HAVE_IPPROTO_HOPOPTS
 #ifndef HAVE_IPPROTO_HOPOPTS
@@ -227,32 +234,25 @@
 #ifndef HAVE_IPPROTO_DSTOPTS
 #define IPPROTO_DSTOPTS 60
 #endif
-
+#endif
 /* IPv6 options structure defined by RFC 3542 */
 #define HAVE_IP6_OPT
 
 /* Common IPv6 extension structure */
 #define HAVE_IP6_EXT
 
+/* Spicy analyzers built in. */
+#define USE_SPICY_ANALYZERS 0
+
 /* String with host architecture (e.g., "linux-x86_64") */
-#define HOST_ARCHITECTURE "openbsd-i386"
+#define HOST_ARCHITECTURE "openbsd-macppc"
 
 /* String with extension of dynamic libraries (e.g., ".so") */
 #define DYNAMIC_PLUGIN_SUFFIX ".so"
 
-/* True if we're building outside of the main Zeek source code tree. */
-#ifndef ZEEK_PLUGIN_INTERNAL_BUILD
-#define ZEEK_PLUGIN_INTERNAL_BUILD true
-#endif
-
-/* A C function that has the Zeek version encoded into its name. */
-#define BRO_VERSION_FUNCTION bro_version_5_0_10_plugin_7
-#ifdef __cplusplus
-extern "C" {
-#endif
-extern const char* BRO_VERSION_FUNCTION();
-#ifdef __cplusplus
-}
+// For builtin plugins, we don't want to include zeek-version.h.
+#ifndef ZEEK_CONFIG_SKIP_VERSION_H
+#include "zeek/zeek-version.h"
 #endif
 
 // GCC uses __SANITIZE_ADDRESS__, Clang uses __has_feature
@@ -266,20 +266,19 @@ extern const char* BRO_VERSION_FUNCTION();
 	#endif
 #endif
 
-// FreeBSD doesn't support LeakSanitizer
 #if defined(ZEEK_ASAN) && !defined(__FreeBSD__)
-	#include <sanitizer/lsan_interface.h>
-	#define ZEEK_LSAN_CHECK(x) __lsan_do_leak_check(x)
-	#define ZEEK_LSAN_ENABLE(x) __lsan_enable(x)
-	#define ZEEK_LSAN_IGNORE(x) __lsan_ignore_object(x)
-	#define ZEEK_LSAN_DISABLE(x) __lsan_disable(x)
-	#define ZEEK_LSAN_DISABLE_SCOPE(x) __lsan::ScopedDisabler x
+    #include <sanitizer/lsan_interface.h>
+    #define ZEEK_LSAN_CHECK(...) __lsan_do_leak_check(__VA_ARGS__)
+    #define ZEEK_LSAN_ENABLE(...) __lsan_enable(__VA_ARGS__)
+    #define ZEEK_LSAN_IGNORE(...) __lsan_ignore_object(__VA_ARGS__)
+    #define ZEEK_LSAN_DISABLE(...) __lsan_disable(__VA_ARGS__)
+    #define ZEEK_LSAN_DISABLE_SCOPE(...) __lsan::ScopedDisabler __VA_ARGS__
 #else
-	#define ZEEK_LSAN_CHECK(x)
-	#define ZEEK_LSAN_ENABLE(x)
-	#define ZEEK_LSAN_IGNORE(x)
-	#define ZEEK_LSAN_DISABLE(x)
-	#define ZEEK_LSAN_DISABLE_SCOPE(x)
+    #define ZEEK_LSAN_CHECK(...)
+    #define ZEEK_LSAN_ENABLE(...)
+    #define ZEEK_LSAN_IGNORE(...)
+    #define ZEEK_LSAN_DISABLE(...)
+    #define ZEEK_LSAN_DISABLE_SCOPE(...)
 #endif
 
 // This part is dependent on calling configure with '--sanitizers=thread'
@@ -301,3 +300,6 @@ extern const char* BRO_VERSION_FUNCTION();
 #else
 	#define ZEEK_DISABLE_TSAN
 #endif
+
+/* compiled with Spicy support */
+/* #undef HAVE_SPICY */
